@@ -7,23 +7,27 @@ import logging
 import os
 import shutil
 import sys
-import warnings
 import traceback
 import typing
+import warnings
 
-from typing import Optional, TextIO
+from typing import Optional, TextIO, Union
 
+
+# isort:maintain_block
 if False:  # TYPE_CHECKING
     from typing import Type  # not in 3.5.{0,1}
+# isort:end_maintain_block
 
-from . import build, install, InstallException, IncompleteInstallationWarning
+
+from . import IncompleteInstallationWarning, InstallException, build, install  # isort:skip # until isort 5.0.0
 
 
 logger = logging.getLogger('install.main')
 
 
 def _showwarning(message, category, filename, lineno, file=None, line=None):
-    # type: (str, Type[Warning], str, int, Optional[TextIO], Optional[str]) -> None
+    # type: (Union[Warning, str], Type[Warning], str, int, Optional[TextIO], Optional[str]) -> None
     prefix = 'WARNING'
     where = '{}:{}'.format(filename, lineno)
     name = '({})'.format(category.__name__)
@@ -65,6 +69,9 @@ if __name__ == '__main__':  # noqa: C901
     parser.add_argument('--destdir', '-d', metavar='/',
                         type=str, default='/',
                         help='destination directory')
+    parser.add_argument('--verify-dependencies', '-t',
+                        action='store_true',
+                        help='check if the dependencies are met')
     # build/install separation
     parser.add_argument('--cache', '-c',
                         action='store_true',
@@ -105,7 +112,7 @@ if __name__ == '__main__':  # noqa: C901
     # Build cache
     if not args.skip_build:
         try:
-            build(args.wheel, cache_dir, args.optimize)
+            build(args.wheel, cache_dir, args.optimize, args.verify_dependencies)
         except InstallException as e:
             _error(str(e))
         except Exception as e:
